@@ -1,23 +1,24 @@
 ; Scheme 9 from Empty Space, Function Library
-; By Nils M Holm, 2010
+; By Nils M Holm, 2010,2012
 ; Placed in the Public Domain
 ;
-; (bit0  integer1 integer2)  ==>  integer | #f
-; (bit*  integer1 integer2)  ==>  integer | #f
-; (bit*c integer1 integer2)  ==>  integer | #f
-; (bita  integer1 integer2)  ==>  integer | #f
-; (bitc* integer1 integer2)  ==>  integer | #f
-; (bitb  integer1 integer2)  ==>  integer | #f
-; (bitn= integer1 integer2)  ==>  integer | #f
-; (bit+  integer1 integer2)  ==>  integer | #f
-; (bitn+ integer1 integer2)  ==>  integer | #f
-; (bit=  integer1 integer2)  ==>  integer | #f
-; (bitcb integer1 integer2)  ==>  integer | #f
-; (bit+c integer1 integer2)  ==>  integer | #f
-; (bitca integer1 integer2)  ==>  integer | #f
-; (bitc+ integer1 integer2)  ==>  integer | #f
-; (bitn* integer1 integer2)  ==>  integer | #f
-; (bit1  integer1 integer2)  ==>  integer | #f
+; (bit0  integer1 integer2 ...)  ==>  integer | #f
+; (bit*  integer1 integer2 ...)  ==>  integer | #f
+; (bit*c integer1 integer2 ...)  ==>  integer | #f
+; (bita  integer1 integer2 ...)  ==>  integer | #f
+; (bitc* integer1 integer2 ...)  ==>  integer | #f
+; (bitb  integer1 integer2 ...)  ==>  integer | #f
+; (bitn= integer1 integer2 ...)  ==>  integer | #f
+; (bit+  integer1 integer2 ...)  ==>  integer | #f
+; (bitn+ integer1 integer2 ...)  ==>  integer | #f
+; (bit=  integer1 integer2 ...)  ==>  integer | #f
+; (bitcb integer1 integer2 ...)  ==>  integer | #f
+; (bit+c integer1 integer2 ...)  ==>  integer | #f
+; (bitca integer1 integer2 ...)  ==>  integer | #f
+; (bitc+ integer1 integer2 ...)  ==>  integer | #f
+; (bitn* integer1 integer2 ...)  ==>  integer | #f
+; (bitsl integer1 integer2 ...)  ==>  integer | #f
+; (bitsr integer1 integer2 ...)  ==>  integer | #f
 ;
 ; (load-from-library "bitops.scm")
 ;
@@ -40,7 +41,7 @@
 ; Table of operations:
 ;
 ; OP    | Description
-; -----------------------
+; ---------------------------------
 ; BIT0  | CLEAR
 ; BIT*  | AND
 ; BIT*C | AND with not(B)
@@ -57,6 +58,8 @@
 ; BITC+ | OR with not(A)
 ; BITN* | NAND
 ; BIT1  | SET
+; BITSL | A shifted left by B bits
+; BITSR | A shifted right by B bits
 ; 
 ; Logical NOT of X can be expressed with (BITCA x 0) or (BITCB 0 x).
 ; The other operand will be ignored.
@@ -64,11 +67,12 @@
 ; See the description of the BIT-OP operator for restrictions of
 ; these procedures.
 ;
-; Example:   (bit0 123 456)  ==>  0
-;            (bit* 127  99)  ==>  99
-;            (bit+  63  64)  ==>  127
-;            (bita 123 456)  ==>  123
-;            (bitb 123 456)  ==>  456
+; Example:   (bit0  123 456)  ==>  0
+;            (bit*  127  99)  ==>  99
+;            (bit+   63  64)  ==>  127
+;            (bita  123 456)  ==>  123
+;            (bitb  123 456)  ==>  456
+;            (bitsl 123   1)  ==>  246
 
 (load-from-library "hof.scm")
 
@@ -88,3 +92,5 @@
 (define bitc+ (curry bit-op 13))
 (define bitn* (curry bit-op 14))
 (define bit1  (curry bit-op 15))
+(define bitsl (curry bit-op 16))
+(define bitsr (curry bit-op 17))
